@@ -27,14 +27,13 @@ import (
 	"github.com/Azure/azure-sdk-for-go/services/compute/mgmt/2018-10-01/compute"
 	"github.com/Azure/azure-sdk-for-go/services/network/mgmt/2018-12-01/network"
 	"github.com/Azure/go-autorest/autorest/to"
-	machinev1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
+	machinev1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
 	"github.com/pkg/errors"
 	apicorev1 "k8s.io/api/core/v1"
 	"k8s.io/klog"
 	"sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1beta1"
 	"sigs.k8s.io/cluster-api-provider-azure/pkg/cloud/azure"
 	"sigs.k8s.io/cluster-api-provider-azure/pkg/cloud/azure/actuators"
-	"sigs.k8s.io/cluster-api-provider-azure/pkg/cloud/azure/converters"
 	"sigs.k8s.io/cluster-api-provider-azure/pkg/cloud/azure/services/availabilityzones"
 	"sigs.k8s.io/cluster-api-provider-azure/pkg/cloud/azure/services/disks"
 	"sigs.k8s.io/cluster-api-provider-azure/pkg/cloud/azure/services/networkinterfaces"
@@ -136,13 +135,6 @@ func (s *Reconciler) Update(ctx context.Context) error {
 		return errors.New("returned incorrect vm interface")
 	}
 
-	// We can now compare the various Azure state to the state we were passed.
-	// We will check immutable state first, in order to fail quickly before
-	// moving on to state that we can mutate.
-	if isMachineOutdated(s.scope.MachineConfig, converters.SDKToVM(vm)) {
-		return errors.Errorf("found attempt to change immutable state")
-	}
-
 	// TODO: Uncomment after implementing tagging.
 	// Ensure that the tags are correct.
 	/*
@@ -429,7 +421,7 @@ func (s *Reconciler) Delete(ctx context.Context) error {
 	}
 
 	if s.scope.MachineConfig.PublicIP {
-		publicIPName, err := azure.GenerateMachinePublicIPName(s.scope.Cluster.Name, s.scope.Machine.Name)
+		publicIPName, err := azure.GenerateMachinePublicIPName(s.scope.ClusterConfig.Name, s.scope.Machine.Name)
 		if err != nil {
 			// Only when the generated name is longer than allowed by the Azure portal
 			// That can happen only when
@@ -451,23 +443,6 @@ func (s *Reconciler) Delete(ctx context.Context) error {
 	return nil
 }
 
-// isMachineOutdated checks that no immutable fields have been updated in an
-// Update request.
-// Returns a bool indicating if an attempt to change immutable state occurred.
-//  - true:  An attempt to change immutable state occurred.
-//  - false: Immutable state was untouched.
-func isMachineOutdated(machineSpec *v1beta1.AzureMachineProviderSpec, vm *v1beta1.VM) bool {
-	// VM Size
-	if !strings.EqualFold(machineSpec.VMSize, vm.VMSize) {
-		return true
-	}
-
-	// TODO: Add additional checks for immutable fields
-
-	// No immutable state changes found.
-	return false
-}
-
 func (s *Reconciler) getZone(ctx context.Context) (string, error) {
 	return to.String(s.scope.MachineConfig.Zone), nil
 }
@@ -507,7 +482,7 @@ func (s *Reconciler) createNetworkInterface(ctx context.Context, nicName string)
 	}
 
 	if s.scope.MachineConfig.PublicIP {
-		publicIPName, err := azure.GenerateMachinePublicIPName(s.scope.Cluster.Name, s.scope.Machine.Name)
+		publicIPName, err := azure.GenerateMachinePublicIPName(s.scope.ClusterConfig.Name, s.scope.Machine.Name)
 		if err != nil {
 			return errors.Wrap(err, "unable to create Public IP")
 		}
